
    // ====== NLProcessor 自然语言处理器 ======
    class NLProcessor {
        constructor() {
            this.synonyms = {
                "牛顿定律": ["牛顿运动定律", "Newton's Laws", "牛顿三定律"],
                "勾股定理": ["毕达哥拉斯定理", "Pythagorean theorem", "直角三角形定理"],
                "相对论": ["爱因斯坦相对论", "Relativity", "时空理论"],
                "春节": ["农历新年", "Chinese New Year", "过年"],
                "圣诞节": ["Christmas", "耶诞节", "圣诞"],
                "量子力学": ["量子理论", "Quantum Mechanics", "量子物理"],
                "微积分": ["Calculus", "微分积分", "高等数学"],
                "人工智能": ["AI", "Artificial Intelligence", "智能技术"],
                "机器学习": ["Machine Learning", "ML", "统计学习"]
            };
            
            this.intentPatterns = {
                calculate: /(计算|等于|求解|算式|calculate|solve|eval)/i,
                definition: /(什么是|解释|定义|什么叫|何为|what is|define|definition)/i,
                culture: /(节日|习俗|传统|文化|festival|culture|tradition)/i,
                math: /(数学|算数|加法|乘法|math|add|multiply)/i,
                greeting: /(你好|hi|hello|greetings)/i,
                goodbye: /(再见|bye|goodbye|see you)/i,
                help: /(帮助|help|命令|usage)/i,
                clear: /(清除|清空|clear|reset)/i,
                reset: /(重置系统|清除所有数据|reset system)/i
            };
            
            this.fallbackResponses = {
                "zh-CN": [
                    "我需要更多上下文来理解您的问题，能否提供更多细节？",
                    "这个问题很有趣，我正在思考如何回答",
                    "您能换个方式表达您的问题吗？",
                    "让我为您分析这个问题...",
                    "这是一个很好的问题，让我为您解答"
                ],
                "en": [
                    "I need more context to understand your question",
                    "Interesting question, let me think about it",
                    "Could you rephrase your question?",
                    "Let me analyze this question...",
                    "That's a good question, let me explain"
                ]
            };
        }

        parse(text) {
            const cleaned = this.cleanText(text);
            return {
                text: cleaned,
                entities: this.extractEntities(text),
                intent: this.detectIntent(text),
                isQuestion: this.isQuestion(text)
            };
        }

        cleanText(text) {
            return text.replace(/[^\w\u4e00-\u9fa5\s]/g, '').replace(/\s+/g, ' ').trim();
        }

        extractEntities(text) {
            const entities = [];
            
            // 精确匹配
            for (const [key, aliases] of Object.entries(this.synonyms)) {
                const pattern = new RegExp(`\\b(${[key, ...aliases].join('|')})\\b`, 'i');
                if (pattern.test(text)) {
                    entities.push(key);
                    break;
                }
            }
            
            // 模糊匹配
            if (entities.length === 0) {
                const keywords = Object.keys(this.synonyms);
                const fuzzyPattern = new RegExp(`(${keywords.join('|')})`, 'i');
                const match = text.match(fuzzyPattern);
                if (match) entities.push(match[1]);
            }
            
            return entities;
        }

        detectIntent(text) {
            for (const [intent, regex] of Object.entries(this.intentPatterns)) {
                if (regex.test(text)) return intent;
            }
            return 'general';
        }

        isQuestion(text) {
            return /(吗|\?|how|why|what|which|who|where)/i.test(text);
        }

        getFallbackResponse(lang = 'zh-CN') {
            const responses = this.fallbackResponses[lang] || this.fallbackResponses["zh-CN"];
            return responses[Math.floor(Math.random() * responses.length)];
        }
    }