    // ====== NeuroCore 核心系统 ======
    class NeuroCore {
        constructor() {
            this.math = new MathCore();
            this.nlp = new NLProcessor();
            this.chatManager = new ChatManager();
            this.isProcessing = false;
            this.currentLang = 'zh-CN';
            
            // 初始化DOM元素
            this.initDOMElements();
            
            // 绑定事件
            this.bindEvents();
            
            // 初始化UI
            this.initUI();
            
            // 检查暗黑模式偏好
            this.checkDarkModePreference();
        }

        initDOMElements() {
            // 侧边栏相关
            this.sidebar = document.getElementById('sidebar');
            this.menuBtn = document.getElementById('menu-btn');
            this.chatList = document.getElementById('chat-list');
            this.newChatSidebarBtn = document.getElementById('new-chat-sidebar');
            
            // 主界面相关
            this.chatContainer = document.getElementById('chat-container');
            this.userInput = document.getElementById('user-input');
            this.sendBtn = document.getElementById('send-btn');
            this.typingIndicator = document.getElementById('typing-indicator');
            this.welcomeMessage = document.querySelector('.welcome-message');
            
            // 模态框相关
            this.langBtn = document.getElementById('lang-btn');
            this.langModal = document.getElementById('lang-modal');
            this.closeLangModal = document.getElementById('close-lang-modal');
            this.langSelect = document.getElementById('lang-select');
            this.confirmLang = document.getElementById('confirm-lang');
            
            this.newChatBtn = document.getElementById('new-chat');
            this.newChatModal = document.getElementById('new-chat-modal');
            this.closeNewChatModal = document.getElementById('close-new-chat-modal');
            this.cancelNewChat = document.getElementById('cancel-new-chat');
            this.confirmNewChat = document.getElementById('confirm-new-chat');
            this.newChatMessage = document.getElementById('new-chat-message');
            
            this.resetModal = document.getElementById('reset-modal');
            this.closeResetModal = document.getElementById('close-reset-modal');
            this.cancelReset = document.getElementById('cancel-reset');
            this.confirmReset = document.getElementById('confirm-reset');
            this.resetMessage = document.getElementById('reset-message');
            
            // 暗黑模式
            this.darkModeBtn = document.getElementById('dark-mode');
            
            // 复制提示
            this.copyToast = document.getElementById('copy-toast');
        }

        bindEvents() {
            // 消息发送
            this.sendBtn.addEventListener('click', () => this.processInput());
            this.userInput.addEventListener('keypress', (e) => {
                if (e.key === 'Enter' && !e.shiftKey && !this.isProcessing) {
                    e.preventDefault();
                    this.processInput();
                }
            });
            
            // 侧边栏
            this.menuBtn.addEventListener('click', () => this.toggleSidebar());
            this.newChatSidebarBtn.addEventListener('click', () => this.showNewChatModal());
            
            // 语言切换
            this.langBtn.addEventListener('click', () => this.showLangModal());
            this.closeLangModal.addEventListener('click', () => this.hideLangModal());
            this.confirmLang.addEventListener('click', () => this.changeLanguage());
            
            // 新对话
            this.newChatBtn.addEventListener('click', () => this.showNewChatModal());
            this.closeNewChatModal.addEventListener('click', () => this.hideNewChatModal());
            this.cancelNewChat.addEventListener('click', () => this.hideNewChatModal());
            this.confirmNewChat.addEventListener('click', () => this.createNewChat());
            
            // 重置系统
            this.closeResetModal.addEventListener('click', () => this.hideResetModal());
            this.cancelReset.addEventListener('click', () => this.hideResetModal());
            this.confirmReset.addEventListener('click', () => this.resetSystem());
            
            // 暗黑模式
            this.darkModeBtn.addEventListener('click', () => this.toggleDarkMode());
            
            // 快捷提问按钮
            this.initQuickPrompts();
        }

        initUI() {
            // 渲染对话列表
            this.renderChatList();
            
            // 如果有当前对话，显示对话内容，否则显示欢迎消息
            const currentChat = this.chatManager.getCurrentChat();
            if (currentChat && currentChat.messages.length > 0) {
                this.welcomeMessage.style.display = 'none';
                this.renderChatMessages(currentChat.messages);
            } else {
                this.showWelcomeMessage();
            }
            
            // 更新UI语言
            this.updateUIForLanguage();
        }

        showWelcomeMessage() {
            this.welcomeMessage.style.display = 'block';
            this.chatContainer.scrollTop = 0;
        }

        async processInput() {
            const input = this.userInput.value.trim();
            if (!input || this.isProcessing) return;

            this.isProcessing = true;
            this.sendBtn.disabled = true;
            this.userInput.disabled = true;
            
            try {
                // 处理特殊命令
                if (this.handleSpecialCommands(input)) {
                    return;
                }
                
                // 如果没有当前对话，创建一个新的
                if (!this.chatManager.getCurrentChat()) {
                    this.chatManager.createChat(input.length > 30 ? input.substring(0, 30) + '...' : input);
                    this.renderChatList();
                }
                
                // 隐藏欢迎消息
                this.welcomeMessage.style.display = 'none';
                
                // 添加用户消息
                const userMessage = {
                    sender: 'user',
                    content: input,
                    timestamp: new Date().toLocaleTimeString(),
                    date: new Date().toLocaleDateString()
                };
                
                await this.addMessage(userMessage);
                this.userInput.value = '';
                this.showTyping();
                
                // 处理输入
                const analysis = this.nlp.parse(input);
                let response;
                
                if (analysis.intent === 'calculate') {
                    const result = this.math.evaluate(input);
                    response = result ? 
                        (this.currentLang === 'zh-CN' ? `计算结果: ${result}` : `Result: ${result}`) : 
                        (this.currentLang === 'zh-CN' ? "无法解析数学表达式，请检查格式" : "Cannot parse math expression");
                } else {
                    response = this.generateResponse(analysis);
                }
                
                // 添加AI响应
                const aiMessage = {
                    sender: 'ai',
                    content: response,
                    timestamp: new Date().toLocaleTimeString(),
                    date: new Date().toLocaleDateString()
                };
                
                await this.addMessage(aiMessage);
            } catch (e) {
                console.error('处理错误:', e);
                // 不再显示错误消息给用户
            } finally {
                this.hideTyping();
                this.sendBtn.disabled = false;
                this.userInput.disabled = false;
                this.userInput.focus();
                this.isProcessing = false;
            }
        }

        handleSpecialCommands(input) {
            const lowerInput = input.toLowerCase();
            
            if (this.nlp.intentPatterns.help.test(lowerInput)) {
                const helpMsg = this.currentLang === 'zh-CN' ? 
                    "可用命令：\n1. 输入数学表达式可直接计算\n2. 输入'帮助'查看帮助信息\n3. 输入'清除'清空当前对话\n4. 输入'重置系统'清理所有本地数据\n5. 点击AI消息右上角图标可复制内容" :
                    "Available commands:\n1. Enter math expressions to calculate\n2. Type 'help' for help\n3. Type 'clear' to reset chat\n4. Type 'reset system' to clear all local data\n5. Click the icon on AI messages to copy content";
                
                const helpMessage = {
                    sender: 'ai',
                    content: helpMsg,
                    timestamp: new Date().toLocaleTimeString(),
                    date: new Date().toLocaleDateString()
                };
                
                this.addMessage(helpMessage);
                return true;
            }
            
            if (this.nlp.intentPatterns.clear.test(lowerInput)) {
                this.createNewChat();
                return true;
            }
            
            if (this.nlp.intentPatterns.reset.test(lowerInput)) {
                this.showResetModal();
                return true;
            }
            
            return false;
        }

        generateResponse(analysis) {
            const { intent, entities, isQuestion, text } = analysis;
            
            // 处理数学计算
            const mathResult = this.math.evaluate(text);
            if (mathResult) {
                return this.currentLang === 'zh-CN' ? 
                    `计算结果: ${mathResult}` : 
                    `Calculation result: ${mathResult}`;
            }

            // 处理特定实体
            if (entities.length > 0) {
                const entity = entities[0];
                const knowledge = this.getKnowledge(entity);
                if (knowledge) return knowledge;
            }

            // 扩展的意图处理
            switch(intent) {
                case 'greeting':
                    return this.currentLang === 'zh-CN' ? 
                        '您好！我是灵枢AI助手，请问有什么可以帮您？' : 
                        'Hello! How can I assist you today?';
                case 'definition':
                    return this.currentLang === 'zh-CN' ?
                        `关于${entities[0] || '这个术语'}的详细解释：\n${this.getDefinition(entities[0] || text)}` :
                        `Definition of ${entities[0] || 'this term'}:\n${this.getDefinition(entities[0] || text)}`;
                case 'culture':
                    return this.currentLang === 'zh-CN' ?
                        `文化传统：${this.getCulturalInfo(entities[0] || text)}` :
                        `Cultural tradition: ${this.getCulturalInfo(entities[0] || text)}`;
                case 'goodbye':
                    return this.currentLang === 'zh-CN' ? 
                        '再见，祝您有美好的一天！' : 
                        'Goodbye, have a nice day!';
                default:
                    return this.nlp.getFallbackResponse(this.currentLang);
            }
        }

        getKnowledge(entity) {
            const knowledgeBase = {
                "勾股定理": "直角三角形斜边平方等于两直角边平方和，公式：c² = a² + b²\n应用：建筑测量、导航等",
                "量子力学": "描述微观粒子运动规律的物理学分支\n核心概念：波函数、不确定性原理、量子纠缠\n创立者：普朗克、玻尔、海森堡等",
                "春节": "中国传统农历新年\n时间：农历正月初一\n主要习俗：贴春联、年夜饭、放鞭炮、拜年、发红包\n持续时间：15天（到元宵节）",
                "微积分": "数学分支，包含微分和积分两大基本运算\n创立者：牛顿和莱布尼茨\n应用：物理学、工程学、经济学等",
                "相对论": "爱因斯坦提出的物理理论\n包含：狭义相对论和广义相对论\n核心概念：时空弯曲、光速不变、质能方程 E=mc²",
                "人工智能": "计算机科学分支，研究智能机器的设计与应用\n主要领域：机器学习、自然语言处理、计算机视觉\n应用：语音助手、推荐系统、自动驾驶等",
                "机器学习": "人工智能的子领域，研究如何通过数据训练算法\n主要方法：监督学习、无监督学习、强化学习\n应用：预测分析、图像识别、自然语言处理等"
            };
            
            const enKnowledgeBase = {
                "Pythagorean theorem": "In a right triangle, the square of the hypotenuse equals the sum of the squares of the other two sides\nFormula: c² = a² + b²",
                "Quantum Mechanics": "Branch of physics describing behavior of matter at atomic scales\nKey concepts: Wave function, Uncertainty principle, Quantum entanglement",
                "Chinese New Year": "Traditional Chinese festival marking the start of lunar new year\nCustoms: Family reunion dinner, red envelopes, fireworks",
                "Calculus": "Branch of mathematics focused on limits, derivatives, integrals\nFounders: Newton and Leibniz",
                "Relativity": "Physics theories by Einstein\nIncludes: Special and General relativity\nKey concepts: Spacetime, E=mc²",
                "Artificial Intelligence": "Field of computer science creating intelligent machines\nAreas: Machine learning, NLP, Computer vision",
                "Machine Learning": "Subfield of AI focusing on algorithms that learn from data\nMethods: Supervised, Unsupervised, Reinforcement learning"
            };
            
            return this.currentLang === 'zh-CN' ? 
                knowledgeBase[entity] || null : 
                enKnowledgeBase[entity] || null;
        }

        getDefinition(term) {
            const definitions = {
                "zh-CN": {
                    "default": "暂时没有关于此术语的详细定义",
                    "人工智能": "模拟人类智能的计算机系统",
                    "区块链": "分布式数据库技术，具有去中心化特点"
                },
                "en": {
                    "default": "No detailed definition available for this term",
                    "AI": "Computer systems mimicking human intelligence",
                    "blockchain": "Distributed database technology with decentralization"
                }
            };
            
            return definitions[this.currentLang][term] || definitions[this.currentLang]["default"];
        }

        getCulturalInfo(topic) {
            const culturalInfo = {
                "zh-CN": {
                    "default": "正在检索相关文化信息...",
                    "春节": "中国最重要的传统节日，家人团聚，辞旧迎新",
                    "中秋节": "农历八月十五，赏月、吃月饼的节日"
                },
                "en": {
                    "default": "Searching cultural information...",
                    "Christmas": "Christian holiday celebrating birth of Jesus, December 25",
                    "Thanksgiving": "American holiday for giving thanks, fourth Thursday in November"
                }
            };
            
            return culturalInfo[this.currentLang][topic] || culturalInfo[this.currentLang]["default"];
        }

        async addMessage(message) {
            // 添加到对话管理器
            this.chatManager.addMessage(this.chatManager.currentChatId, message);
            
            // 渲染消息
            const div = document.createElement('div');
            div.className = `message ${message.sender}-message`;
            
            if (message.sender === 'user') {
                div.innerHTML = `
                    <div class="bubble">${message.content}</div>
                    <div class="avatar"><span class="material-icons">person</span></div>
                    <div class="timestamp">${message.timestamp}</div>
                `;
            } else {
                div.innerHTML = `
                    <div class="avatar"><span class="material-icons">smart_toy</span></div>
                    <div class="bubble">
                        <div class="thinking-steps"></div>
                        <div class="message-content">${message.content}</div>
                        <button class="copy-btn" title="${this.currentLang === 'zh-CN' ? '复制内容' : 'Copy content'}">
                            <span class="material-icons" style="font-size: 16px;">content_copy</span>
                        </button>
                    </div>
                    <div class="timestamp">${message.timestamp}</div>
                `;
            }
            
            this.chatContainer.insertBefore(div, this.typingIndicator);
            await this.scrollToBottom();
            
            // 添加复制功能
            if (message.sender === 'ai') {
                const copyBtn = div.querySelector('.copy-btn');
                copyBtn.addEventListener('click', () => {
                    this.copyToClipboard(message.content);
                });
            }
            
            // AI消息的动画效果
            if (message.sender === 'ai') {
                const stepsContainer = div.querySelector('.thinking-steps');
                const messageContent = div.querySelector('.message-content');
                messageContent.style.display = 'none';
                
                // 显示思考过程
                const steps = this.currentLang === 'zh-CN' ? 
                    ['正在分析问题...', '检索知识库...', '生成响应...'] :
                    ['Analyzing question...', 'Searching knowledge...', 'Generating response...'];
                
                for (const step of steps) {
                    await this.showThinkingStep(step, stepsContainer);
                    await this.delay(800);
                }
                
                // 显示最终消息
                messageContent.style.display = 'block';
                await this.typeText(message.content, messageContent);
            }
        }

        copyToClipboard(text) {
            navigator.clipboard.writeText(text).then(() => {
                this.showCopyToast();
            }).catch(err => {
                console.error('复制失败:', err);
            });
        }

        showCopyToast() {
            this.copyToast.textContent = this.currentLang === 'zh-CN' ? 
                '✓ 已复制' : '✓ Copied';
            this.copyToast.classList.add('show');
            
            setTimeout(() => {
                this.copyToast.classList.remove('show');
            }, 2000);
        }

        renderChatMessages(messages) {
            this.chatContainer.innerHTML = '';
            
            if (messages.length === 0) {
                this.showWelcomeMessage();
                return;
            }
            
            messages.forEach(message => {
                const div = document.createElement('div');
                div.className = `message ${message.sender}-message`;
                
                if (message.sender === 'user') {
                    div.innerHTML = `
                        <div class="bubble">${message.content}</div>
                        <div class="avatar"><span class="material-icons">person</span></div>
                        <div class="timestamp">${message.timestamp}</div>
                    `;
                } else {
                    div.innerHTML = `
                        <div class="avatar"><span class="material-icons">smart_toy</span></div>
                        <div class="bubble">
                            <div class="message-content">${message.content}</div>
                            <button class="copy-btn" title="${this.currentLang === 'zh-CN' ? '复制内容' : 'Copy content'}">
                                <span class="material-icons" style="font-size: 16px;">content_copy</span>
                            </button>
                        </div>
                        <div class="timestamp">${message.timestamp}</div>
                    `;
                    
                    // 为历史消息添加复制功能
                    const copyBtn = div.querySelector('.copy-btn');
                    copyBtn.addEventListener('click', () => {
                        this.copyToClipboard(message.content);
                    });
                }
                
                this.chatContainer.appendChild(div);
            });
            
            this.chatContainer.appendChild(this.typingIndicator);
            this.scrollToBottom();
        }

        renderChatList() {
            this.chatList.innerHTML = '';
            
            if (this.chatManager.chats.length === 0) {
                const emptyMsg = document.createElement('div');
                emptyMsg.className = 'chat-item';
                emptyMsg.textContent = this.currentLang === 'zh-CN' ? '暂无对话历史' : 'No chat history';
                this.chatList.appendChild(emptyMsg);
                return;
            }
            
            this.chatManager.chats.forEach(chat => {
                const chatItem = document.createElement('div');
                chatItem.className = `chat-item ${chat.id === this.chatManager.currentChatId ? 'active' : ''}`;
                chatItem.textContent = chat.title;
                chatItem.addEventListener('click', () => {
                    this.switchChat(chat.id);
                });
                
                // 添加删除按钮
                const deleteBtn = document.createElement('button');
                deleteBtn.className = 'delete-chat-btn';
                deleteBtn.innerHTML = '<span class="material-icons">delete</span>';
                deleteBtn.addEventListener('click', (e) => {
                    e.stopPropagation();
                    this.deleteChat(chat.id);
                });
                
                chatItem.appendChild(deleteBtn);
                this.chatList.appendChild(chatItem);
            });
        }

        switchChat(chatId) {
            this.chatManager.switchChat(chatId);
            const chat = this.chatManager.getCurrentChat();
            this.renderChatList();
            
            if (chat && chat.messages.length > 0) {
                this.welcomeMessage.style.display = 'none';
                this.renderChatMessages(chat.messages);
            } else {
                this.showWelcomeMessage();
            }
            
            this.toggleSidebar(false);
        }

        deleteChat(chatId) {
            if (confirm(this.currentLang === 'zh-CN' ? 
                '确定要删除这个对话吗？此操作无法撤销。' : 
                'Are you sure you want to delete this chat? This cannot be undone.')) {
                this.chatManager.deleteChat(chatId);
                this.renderChatList();
                
                // 如果删除的是当前对话，显示欢迎消息
                if (!this.chatManager.getCurrentChat()) {
                    this.showWelcomeMessage();
                    this.chatContainer.innerHTML = '';
                    this.chatContainer.appendChild(this.typingIndicator);
                }
            }
        }

        async showThinkingStep(text, container) {
            const stepDiv = document.createElement('div');
            stepDiv.className = 'thinking-step';
            stepDiv.innerHTML = `
                <span class="material-icons">hourglass_empty</span>
                <span>${text}</span>
            `;
            container.appendChild(stepDiv);
            await this.scrollToBottom();
        }

        async typeText(text, element) {
            element.innerHTML = '';
            const cursor = document.createElement('span');
            cursor.className = 'cursor';
            element.appendChild(cursor);
            
            for (let i = 0; i < text.length; i++) {
                await this.delay(20);
                
                const charSpan = document.createElement('span');
                charSpan.className = 'typing-animation';
                charSpan.textContent = text[i];
                
                if (i === text.length - 1) {
                    element.removeChild(cursor);
                }
                
                element.insertBefore(charSpan, cursor);
                setTimeout(() => {
                    charSpan.style.animation = 'typing 0.1s forwards';
                }, 10);
                
                await this.scrollToBottom();
            }
        }

        showTyping() {
            this.typingIndicator.style.display = 'flex';
            this.scrollToBottom();
        }

        hideTyping() {
            this.typingIndicator.style.display = 'none';
        }

        async scrollToBottom() {
            await this.delay(10);
            this.chatContainer.scrollTop = this.chatContainer.scrollHeight;
        }

        delay(ms) {
            return new Promise(resolve => setTimeout(resolve, ms));
        }

        createNewChat() {
            this.hideNewChatModal();
            this.chatManager.createChat(this.currentLang === 'zh-CN' ? '新对话' : 'New chat');
            this.renderChatList();
            this.showWelcomeMessage();
            this.chatContainer.innerHTML = '';
            this.chatContainer.appendChild(this.typingIndicator);
        }

        showNewChatModal() {
            this.newChatMessage.textContent = this.currentLang === 'zh-CN' ? 
                '确定要开始新的对话吗？当前对话将被保存。' : 
                'Are you sure you want to start a new chat? Current chat will be saved.';
            this.newChatModal.classList.add('active');
        }

        hideNewChatModal() {
            this.newChatModal.classList.remove('active');
        }

        showResetModal() {
            this.resetMessage.textContent = this.currentLang === 'zh-CN' ? 
                '确定要重置系统吗？这将清除所有本地存储的对话和数据，且无法恢复！' : 
                'Are you sure you want to reset the system? This will delete ALL locally stored chats and data, and cannot be undone!';
            this.resetModal.classList.add('active');
        }

        hideResetModal() {
            this.resetModal.classList.remove('active');
        }

        resetSystem() {
            this.hideResetModal();
            this.chatManager.clearAllChats();
            localStorage.removeItem('darkMode');
            
            // 重置UI
            this.showWelcomeMessage();
            this.chatContainer.innerHTML = '';
            this.chatContainer.appendChild(this.typingIndicator);
            this.renderChatList();
            
            // 重置暗黑模式
            document.body.classList.remove('dark-mode');
            this.darkModeBtn.innerHTML = '<span class="material-icons">dark_mode</span>';
            
            const resetMsg = this.currentLang === 'zh-CN' ? 
                "系统已重置，所有本地数据已清除" : 
                "System reset, all local data has been cleared";
            
            const resetMessage = {
                sender: 'ai',
                content: resetMsg,
                timestamp: new Date().toLocaleTimeString(),
                date: new Date().toLocaleDateString()
            };
            
            this.addMessage(resetMessage);
        }

        showLangModal() {
            this.langSelect.value = this.currentLang;
            this.langModal.classList.add('active');
        }

        hideLangModal() {
            this.langModal.classList.remove('active');
        }

        changeLanguage() {
            this.currentLang = this.langSelect.value;
            this.updateUIForLanguage();
            this.hideLangModal();
            
            // 更新当前对话的显示
            const currentChat = this.chatManager.getCurrentChat();
            if (currentChat) {
                this.renderChatMessages(currentChat.messages);
            }
        }

        toggleSidebar(show = null) {
            if (show === null) {
                this.sidebar.classList.toggle('active');
            } else {
                show ? this.sidebar.classList.add('active') : this.sidebar.classList.remove('active');
            }
        }

        toggleDarkMode() {
            document.body.classList.toggle('dark-mode');
            const isDark = document.body.classList.contains('dark-mode');
            localStorage.setItem('darkMode', isDark);
            this.darkModeBtn.innerHTML = isDark ? 
                '<span class="material-icons">light_mode</span>' : 
                '<span class="material-icons">dark_mode</span>';
        }

        initQuickPrompts() {
            document.querySelectorAll('.prompt-btn').forEach(btn => {
                btn.addEventListener('click', () => {
                    const prompt = btn.dataset.prompt;
                    this.userInput.value = prompt;
                    this.userInput.focus();
                });
            });
        }

        updateUIForLanguage() {
            this.userInput.placeholder = this.currentLang === 'zh-CN' ? '输入您的问题...' : 'Type your question...';
            document.querySelector('.welcome-message h2').textContent = 
                this.currentLang === 'zh-CN' ? '您好！我是灵枢智能助手' : 'Hello! I am NeuroCore AI';
            document.querySelector('.welcome-message p').textContent = 
                this.currentLang === 'zh-CN' ? '我可以帮助您解决以下问题：' : 'I can help you with:';
            document.querySelector('.sidebar-title').textContent = 
                this.currentLang === 'zh-CN' ? '对话历史' : 'Chat History';
            document.getElementById('send-btn').lastChild.textContent = 
                this.currentLang === 'zh-CN' ? '发送' : 'Send';
            document.getElementById('new-chat-sidebar').lastChild.textContent = 
                this.currentLang === 'zh-CN' ? '新对话' : 'New chat';
        }

        checkDarkModePreference() {
            const prefersDark = window.matchMedia('(prefers-color-scheme: dark)').matches;
            const savedMode = localStorage.getItem('darkMode');
            
            if (savedMode === 'true' || (savedMode === null && prefersDark)) {
                document.body.classList.add('dark-mode');
                this.darkModeBtn.innerHTML = '<span class="material-icons">light_mode</span>';
            }
        }
    }

    // 初始化应用
    document.addEventListener('DOMContentLoaded', () => {
        const app = new NeuroCore();
    });
    