 // ====== MathCore 数学计算引擎 ======
    class MathCore {
        constructor() {
            this.operators = {
                '+': { prec: 2, assoc: 'L', fn: (a, b) => a + b },
                '-': { prec: 2, assoc: 'L', fn: (a, b) => a - b },
                '*': { prec: 3, assoc: 'L', fn: (a, b) => a * b },
                '/': { prec: 3, assoc: 'L', fn: (a, b) => a / b },
                '^': { prec: 4, assoc: 'R', fn: (a, b) => Math.pow(a, b) },
                '%': { prec: 3, assoc: 'L', fn: (a, b) => a % b }
            };
            
            this.constants = {
                'π': Math.PI,
                'pi': Math.PI,
                'e': Math.E
            };
            
            this.functions = {
                'sin': Math.sin,
                'cos': Math.cos,
                'tan': Math.tan,
                'sqrt': Math.sqrt,
                'log': Math.log10,
                'ln': Math.log,
                'abs': Math.abs,
                'ceil': Math.ceil,
                'floor': Math.floor,
                'round': Math.round
            };
        }

        tokenize(expr) {
            const tokens = [];
            let numBuffer = '';
            let funcBuffer = '';
            let isFunc = false;
            
            const pushNum = () => {
                if (numBuffer) {
                    tokens.push(parseFloat(numBuffer));
                    numBuffer = '';
                }
            };

            const pushFunc = () => {
                if (funcBuffer) {
                    tokens.push(funcBuffer.toLowerCase());
                    funcBuffer = '';
                    isFunc = false;
                }
            };

            for (let i = 0; i < expr.length; i++) {
                const c = expr[i];
                
                if (/\d|\./.test(c)) {
                    if (isFunc) {
                        funcBuffer += c;
                    } else {
                        numBuffer += c;
                    }
                } else if (/[a-z]/i.test(c)) {
                    if (numBuffer) pushNum();
                    isFunc = true;
                    funcBuffer += c;
                } else {
                    pushNum();
                    pushFunc();
                    
                    if (c in this.constants) {
                        tokens.push(this.constants[c]);
                    } else if (c.trim()) {
                        tokens.push(c);
                    }
                }
            }
            
            pushNum();
            pushFunc();
            return tokens;
        }

        toRPN(tokens) {
            const output = [];
            const stack = [];
            
            tokens.forEach(token => {
                if (typeof token === 'number') {
                    output.push(token);
                } else if (token in this.operators) {
                    while (stack.length > 0 && 
                          stack[stack.length-1] !== '(' &&
                          (this.operators[stack[stack.length-1]].prec > this.operators[token].prec || 
                          (this.operators[stack[stack.length-1]].prec === this.operators[token].prec &&
                           this.operators[token].assoc === 'L'))) {
                        output.push(stack.pop());
                    }
                    stack.push(token);
                } else if (token === '(') {
                    stack.push(token);
                } else if (token === ')') {
                    while (stack.length > 0 && stack[stack.length-1] !== '(') {
                        output.push(stack.pop());
                    }
                    stack.pop();
                } else if (typeof token === 'string' && /^[a-z]+$/.test(token)) {
                    stack.push(token);
                }
            });
            
            while (stack.length > 0) {
                output.push(stack.pop());
            }
            return output;
        }

        evaluate(expr) {
            try {
                // 预处理表达式
                expr = expr.replace(/\s/g, '')
                          .replace(/(\d)\(/g, '$1*(')
                          .replace(/\)(\d)/g, ')*$1')
                          .replace(/\)\(/g, ')*(');
                
                const tokens = this.tokenize(expr);
                const rpn = this.toRPN(tokens);
                const stack = [];
                
                for (const token of rpn) {
                    if (typeof token === 'number') {
                        stack.push(token);
                    } else if (token in this.operators) {
                        const b = stack.pop();
                        const a = stack.pop();
                        stack.push(this.operators[token].fn(a, b));
                    } else if (typeof token === 'string') {
                        // 处理函数
                        if (token in this.functions) {
                            const arg = stack.pop();
                            stack.push(this.functions[token](arg));
                        } else {
                            throw new Error(`未知函数: ${token}`);
                        }
                    }
                }
                
                if (stack.length !== 1) {
                    throw new Error('表达式不完整');
                }
                
                const result = stack.pop();
                return Number.isInteger(result) ? result.toString() : parseFloat(result.toFixed(6)).toString();
            } catch (e) {
                console.error('计算错误:', e);
                return null;
            }
        }
    }
